Engine
======

A wrapper library that integrates GeoEngine and MMLab libraries for GeoSpatial ML development.

Installation
------------

.. code:: shell

   pip install torch torchvision
   pip install -U openmim
   mim install "mmengine>=0.6.0"
   mim install "mmcv>=2.0.0rc4,<2.1.0"
   mim install "mmdet>=3.0.0rc6,<3.1.0"
   mim install "mmyolo"
   mim install "mmsegmentation>=1.0.0"
   pip install geolibs

License
-------

GPLv3

Documentation
-------------

View documentation ``here <https://engine.granular.ai/>``\ \_
